@@ -50,18 +50,27 @@ FAILEDOPERATION_CAMSIGANDAUTHERROR = 'FailedOperation.CamSigAndAuthError'
 # 获取项目信息失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_CDBCGWCONNECTERROR = 'FailedOperation.CdbCgwConnectError'
 
+# 不支持新增基础网络。
+FAILEDOPERATION_CREATEBASICNETWORKDENIEDERROR = 'FailedOperation.CreateBasicNetworkDeniedError'
+
 # 创建续费订单失败。
 FAILEDOPERATION_CREATEORDERFAILED = 'FailedOperation.CreateOrderFailed'
 
 # 管控元数据库访问失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_DATABASEACCESSERROR = 'FailedOperation.DatabaseAccessError'
 
+# 数据操作失败，请联系客服进行处理。
+FAILEDOPERATION_DATABASEAFFECTEDERROR = 'FailedOperation.DatabaseAffectedError'
+
 # VPC删除路由失败。
 FAILEDOPERATION_DELETEALLROUTE = 'FailedOperation.DeleteAllRoute'
 
 # 资源解绑项目失败。
 FAILEDOPERATION_DELETERESOURCEPROJECTTAGERROR = 'FailedOperation.DeleteResourceProjectTagError'
 
+# 资源解绑标签失败。
+FAILEDOPERATION_DELETERESOURCESTOTAGERROR = 'FailedOperation.DeleteResourcesToTagError'
+
 # ES访问失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_ESCONNECTERROR = 'FailedOperation.ESConnectError'
 
@@ -104,6 +113,9 @@ FAILEDOPERATION_MASTERINSTANCEQUERYERROR = 'FailedOperation.MasterInstanceQueryE
 # 修改只读组配置失败。
 FAILEDOPERATION_MODIFYROGROUPERROR = 'FailedOperation.ModifyROGroupError'
 
+# 不符合资源所拥有的的网络数量要求。
+FAILEDOPERATION_NETWORKNUMLIMITERROR = 'FailedOperation.NetworkNumLimitError'
+
 # 访问管控服务失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_OSSACCESSERROR = 'FailedOperation.OssAccessError'
 
@@ -158,6 +170,9 @@ FAILEDOPERATION_ROGROUPNUMEXCEEDERROR = 'FailedOperation.ROGroupNumExceedError'
 # 只读实例已在其他只读组。
 FAILEDOPERATION_ROINSTANCEHASINROGROUPERROR = 'FailedOperation.ROInstanceHasInROGroupError'
 
+# Serverless实例不支持此操作。
+FAILEDOPERATION_SERVERLESSNOTSUPPORTEDERROR = 'FailedOperation.ServerlessNotSupportedError'
+
 # 访问内部服务失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_SERVICEACCESSERROR = 'FailedOperation.ServiceAccessError'
 
@@ -224,6 +239,9 @@ INTERNALERROR_FLOWERROR = 'InternalError.FlowError'
 # 管控系统元数据访问异常，请联系客服处理。
 INTERNALERROR_INSTANCEDATAERROR = 'InternalError.InstanceDataError'
 
+# 后台数据解析失败，请联系客服进行处理。
+INTERNALERROR_MARSHALERROR = 'InternalError.MarshalError'
+
 # 系统错误。出现这种错误时，请联系客服支持。
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
@@ -365,6 +383,9 @@ INVALIDPARAMETERVALUE_PARAMETERHANDLEERROR = 'InvalidParameterValue.ParameterHan
 # 参数长度超过限制。
 INVALIDPARAMETERVALUE_PARAMETERLENGTHLIMITERROR = 'InvalidParameterValue.ParameterLengthLimitError'
 
+# 存在无效的参数值。
+INVALIDPARAMETERVALUE_PARAMETEROUTRANGEERROR = 'InvalidParameterValue.ParameterOutRangeError'
+
 # 参数值超过上限。
 INVALIDPARAMETERVALUE_PARAMETERVALUEEXCEEDERROR = 'InvalidParameterValue.ParameterValueExceedError'
 
@@ -407,6 +428,9 @@ OPERATIONDENIED_DTSINSTANCESTATUSERROR = 'OperationDenied.DTSInstanceStatusError
 # 您没有权限操作当前资源。
 OPERATIONDENIED_INSTANCEACCESSDENIEDERROR = 'OperationDenied.InstanceAccessDeniedError'
 
+# 不支持ipv6。
+OPERATIONDENIED_INSTANCEIPV6NOTSUPPORTEDERROR = 'OperationDenied.InstanceIpv6NotSupportedError'
+
 # 实例状态限制当前操作。
 OPERATIONDENIED_INSTANCESTATUSDENIEDERROR = 'OperationDenied.InstanceStatusDeniedError'
 
@@ -428,6 +452,9 @@ OPERATIONDENIED_POSTPAIDPAYMODEERROR = 'OperationDenied.PostPaidPayModeError'
 # 只读组状态限制当前操作。
 OPERATIONDENIED_ROGROUPSTATUSERROR = 'OperationDenied.ROGroupStatusError'
 
+# 只读实例不支持ipv6。
+OPERATIONDENIED_ROINSTANCEIPV6NOTSUPPORTEDERROR = 'OperationDenied.ROInstanceIpv6NotSupportedError'
+
 # 只读节点总数不能超过上限值。
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
